@@ -52,7 +52,7 @@ class Board(object):
         self._declarer_index = -1
         self.contract = Contract()
         self.auction = Auction()
-        self.tricks = self._create_tricks()
+        self.tricks = []
         self.NS_tricks = 0
         self.EW_tricks = 0
         self.play_notes = {}
@@ -118,13 +118,13 @@ class Board(object):
         """Return a str string for the object."""
         return f'Board("{self._identifier}")'
 
-    @staticmethod
-    def _create_tricks():
-        """Return a dict of the board's tricks."""
-        tricks = {}
-        for index in range(13):
-            tricks[index] = Trick(index)
-        return tricks
+    # @staticmethod
+    # def _create_tricks():
+    #     """Return a dict of the board's tricks."""
+    #     tricks = {}
+    #     for index in range(13):
+    #         tricks[index] = Trick(index)
+    #     return tricks
 
     @property
     def vulnerable(self):
