@@ -1,8 +1,9 @@
 """Constants used in many bridgeobjects modules."""
 
-__all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'CALLS', 'CONTRACTS', 'SUIT_NAMES', 'RANKS',
+__all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'CALLS', 'CONTRACTS', 'SUIT_NAMES',  'RANKS',
            'SUITS', 'BALANCED_SHAPES', 'SEMI_BALANCED_SHAPES',
-           'SHAPES', 'SHAPE_PROBABILITIES', 'HONOUR_POINTS', 'CARD_NAMES']
+           'SHAPES', 'SHAPE_PROBABILITIES', 'HONOUR_POINTS', 'CARD_NAMES',
+           'DISPLAY_SUIT_ORDER']
 
 from .suit import Clubs, Diamonds, Hearts, Spades
 
@@ -54,6 +55,8 @@ RANKS = ['x', '2', '3', '4', '5', '6', '7', '8', '9', 'T', 'J', 'Q', 'K', 'A']
 #: Suits dictionary
 SUITS = {'C': Clubs(), 'D': Diamonds(), 'H': Hearts(), 'S': Spades()}
 
+DISPLAY_SUIT_ORDER = 'SHCD'
+
 
 def _make_cards_names():
     """Return a list of cards."""
