@@ -6,7 +6,7 @@ from .denomination import Denomination
 from .suit import Suit, Spades, Hearts, Diamonds, Clubs
 from .constants import (SUIT_NAMES, RANKS, SUITS, HONOUR_POINTS,
                         BALANCED_SHAPES, SEMI_BALANCED_SHAPES,
-                        CARD_NAMES)
+                        CARD_NAMES, DISPLAY_SUIT_ORDER)
 
 __all__ = ['Hand']
 
@@ -43,13 +43,14 @@ class Hand(object):
 
     CANDIDATES_4441 = {'S': SUITS['H'], 'H': SUITS['S'], 'D': SUITS['H'], 'C': SUITS['S']}
 
+
     def __init__(self, cards=None):
         """
         Create a list of cards from the input parameter and
         check that the hand is valid and assign properties.
         """
         # display attributes
-        self._suit_order = 'SHCD'
+        self._suit_order = DISPLAY_SUIT_ORDER
         self._high_card_left = True
 
         # attributes set once the cards are known for the hand
@@ -294,6 +295,15 @@ class Hand(object):
             self._shape = self._get_shape()
         return self._shape
 
+    def suit_length(self, suit):
+        """Return the length of a suit."""
+        if isinstance(suit, str):
+            suit = Suit(suit)
+        if suit.is_suit:
+            return self.suit_holding[suit]
+        else:
+            raise TypeError("suit must be a suit instance")
+
     @property
     def suits_by_length(self):
         """Return the list of hand's suits, in descending order by holding."""
@@ -510,7 +520,7 @@ class Hand(object):
         """Return the card list sorted according to the suit order and high card left."""
         if high_card_left is None:
             high_card_left = self._high_card_left
-        return self._sort_cards(self.cards, suit_order=suit_order, high_card_left=high_card_left)
+        return self.sort_card_list(self.cards, suit_order=suit_order, high_card_left=high_card_left)
 
     def suit_points(self, suit):
         """Return the number of high card points in that suit."""
@@ -828,10 +838,11 @@ class Hand(object):
             hand_list.append(''.join(suit_cards))
         return '.'.join(hand_list)
 
-    def _sort_cards(self, cards, suit_order, high_card_left):
+    @staticmethod
+    def sort_card_list(cards, suit_order=None, high_card_left=True):
         """Return a list of cards sorted by suit and rank."""
         if not suit_order:
-            suit_order = self._suit_order
+            suit_order = DISPLAY_SUIT_ORDER
         raw_cards = [None]*52
         for card in cards:
             suit = suit_order.index(card.suit.name)
@@ -908,4 +919,3 @@ class Hand(object):
                 if ten in cards and nine in cards:
                     internal_sequences.append(ten)
         return internal_sequences
-
